@@ -5,6 +5,8 @@ use warnings;
 use base qw(Class::Accessor::Fast);
 __PACKAGE__->mk_ro_accessors(qw(id));
 
+use File::Spec;
+
 sub new {
     my ($class, @args) = @_;
 
@@ -14,17 +16,22 @@ sub new {
 
 sub _dir {
     my ($self) = @_;
-    sprintf('/tmp/test-synchronized-%d.lock', $self->id);
+
+    File::Spec->catfile(
+        File::Spec->tmpdir,
+        sprintf('test-synchronized-%d.lock', $self->id),
+    );
 }
 
 sub lock {
     my ($self) = @_;
 
-    while (-e $self->_dir) {
+    while (1) {
+        if (! -d  $self->_dir) {
+            return if mkdir($self->_dir);
+        }
         sleep(1);
     }
-
-    mkdir($self->_dir);
 }
 
 sub unlock {
@@ -33,4 +40,8 @@ sub unlock {
     rmdir($self->_dir);
 }
 
+sub DESTROY {
+    shift->unlock;
+}
+
 1;
